client

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2023 License: Apache-2.0 Imports: 22 Imported by: 0

Documentation

Overview

Package client is a generated GoMock package.

Index

Constants

const (
	ErrDeliveryTimeout = 601
	ErrUndefined       = 602
)

Variables

var (
	Success               = Result{}
	DeliveryTimeout       = Result{ErrDeliveryTimeout, errors.New("DeliveryTimeout")}
	Forbidden             = newResultByHTTPCode(nethttp.StatusForbidden)
	RequestEntityTooLarge = newResultByHTTPCode(nethttp.StatusRequestEntityTooLarge)
)

Functions

This section is empty.

Types

type EventClient

type EventClient interface {
	Sender
}

func NewAwsLambdaClient

func NewAwsLambdaClient(accessKeyID, secretKeyID, arnStr string) EventClient

func NewGCloudFunctionClient added in v0.4.0

func NewGCloudFunctionClient(url, credentialJSON string) EventClient

func NewGRPCClient added in v0.5.7

func NewGRPCClient(url string) EventClient

func NewHTTPClient

func NewHTTPClient(url string) EventClient

type MockEventClient

type MockEventClient struct {
	// contains filtered or unexported fields
}

MockEventClient is a mock of EventClient interface.

func NewMockEventClient

func NewMockEventClient(ctrl *gomock.Controller) *MockEventClient

NewMockEventClient creates a new mock instance.

func (*MockEventClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockEventClient) Send

func (m *MockEventClient) Send(ctx context.Context, events ...*v2.Event) Result

Send mocks base method.

type MockEventClientMockRecorder

type MockEventClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockEventClientMockRecorder is the mock recorder for MockEventClient.

func (*MockEventClientMockRecorder) Send

func (mr *MockEventClientMockRecorder) Send(ctx interface{}, events ...interface{}) *gomock.Call

Send indicates an expected call of Send.

type MockSender

type MockSender struct {
	// contains filtered or unexported fields
}

MockSender is a mock of Sender interface.

func NewMockSender

func NewMockSender(ctrl *gomock.Controller) *MockSender

NewMockSender creates a new mock instance.

func (*MockSender) EXPECT

func (m *MockSender) EXPECT() *MockSenderMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockSender) Send

func (m *MockSender) Send(ctx context.Context, events ...*v2.Event) Result

Send mocks base method.

type MockSenderMockRecorder

type MockSenderMockRecorder struct {
	// contains filtered or unexported fields
}

MockSenderMockRecorder is the mock recorder for MockSender.

func (*MockSenderMockRecorder) Send

func (mr *MockSenderMockRecorder) Send(ctx interface{}, events ...interface{}) *gomock.Call

Send indicates an expected call of Send.

type Result

type Result struct {
	StatusCode int
	Err        error
}

type Sender

type Sender interface {
	Send(ctx context.Context, events ...*ce.Event) Result
}

Jump to